// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/base"
	model "LAPP_GAAS_GFrame_BACKEND/models/base"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : PrintDetailDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : PrintDetail的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 13:08:46
 *
 ******************************************************************************/
type PrintDetailDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewPrintDetailDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个PrintDetailDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : PrintDetailDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 13:08:46
 *
 ******************************************************************************/
func NewPrintDetailDAOImplement(session *xorm.Session, plantNr int, userid string) *PrintDetailDAOImplement {
	return &PrintDetailDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.InsertOne
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) InsertOne(entity *model.PrintDetail) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.PrintDetail.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) DeleteOne(printHeadId string, pos int) error {
	_, err := impl.session.Table(meta.PrintDetail.TableName).ID(core.PK{impl.plantNr, printHeadId, pos}).Delete(meta.PrintDetail.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.SelectOne
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) SelectOne(printHeadId string, pos int) (*model.PrintDetail, error) {
	var data model.PrintDetail
	ok, err := impl.session.Table(meta.PrintDetail.TableName).ID(core.PK{impl.plantNr, printHeadId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) UpdateOne(entity *model.PrintDetail) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.PrintDetail.TableName).Cols(meta.PrintDetail.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.Insert
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) Insert(entities *[]model.PrintDetail) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.PrintDetail.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.Delete
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) Delete(entities *[]model.PrintDetail) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.PrintDetail.TableName).ID(entity.GetKey()).Delete(meta.PrintDetail.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.PrintDetail.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.PrintDetail.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.Select
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.PrintDetail, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.PrintDetail.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.PrintDetail, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.PrintDetail.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.PrintDetail.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.PrintDetail, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.PrintDetail.TableName).SQL("select * from "+meta.PrintDetail.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.Update
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) Update(entities *[]model.PrintDetail) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.PrintDetail.TableName).Cols(meta.PrintDetail.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/PrintDetailDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *PrintDetailDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.PrintDetail, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.PrintDetail.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.PrintDetail_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.PrintDetail.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
