// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/base"
	model "LAPP_GAAS_GFrame_BACKEND/models/base"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
*
* @Struct Name              : UomDAOImplement
*-----------------------------------------------------------------------------
*
* @Description              : Uom的数据访问对象实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-24 09:53:49
*
******************************************************************************/
type UomDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewUomDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个UomDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : UomDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-24 09:53:49
 *
 ******************************************************************************/
func NewUomDAOImplement(session *xorm.Session, plantNr int, userid string) *UomDAOImplement {
	return &UomDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.InsertOne
 *
 ******************************************************************************/
func (impl *UomDAOImplement) InsertOne(entity *model.Uom) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.Uom.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *UomDAOImplement) DeleteOne(uomId string) error {
	_, err := impl.session.Table(meta.Uom.TableName).ID(core.PK{impl.plantNr, uomId}).Delete(meta.Uom.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.SelectOne
 *
 ******************************************************************************/
func (impl *UomDAOImplement) SelectOne(uomId string) (*model.Uom, error) {
	var data model.Uom
	ok, err := impl.session.Table(meta.Uom.TableName).ID(core.PK{impl.plantNr, uomId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *UomDAOImplement) UpdateOne(entity *model.Uom) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.Uom.TableName).Cols(meta.Uom.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.Insert
 *
 ******************************************************************************/
func (impl *UomDAOImplement) Insert(entities *[]model.Uom) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.Uom.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.Delete
 *
 ******************************************************************************/
func (impl *UomDAOImplement) Delete(entities *[]model.Uom) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.Uom.TableName).ID(entity.GetKey()).Delete(meta.Uom.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *UomDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.Uom.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.Uom.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.Select
 *
 ******************************************************************************/
func (impl *UomDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Uom, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.Uom.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.Uom, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *UomDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.Uom.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.Uom.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.Uom, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.Uom.TableName).SQL("select * from "+meta.Uom.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.Update
 *
 ******************************************************************************/
func (impl *UomDAOImplement) Update(entities *[]model.Uom) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.Uom.TableName).Cols(meta.Uom.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/UomDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *UomDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.Uom, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.Uom.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.Uom_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.Uom.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
