// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/base"
	model "LAPP_GAAS_GFrame_BACKEND/models/base"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WeekModelDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WeekModel的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
type WeekModelDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWeekModelDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WeekModelDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WeekModelDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func NewWeekModelDAOImplement(session *xorm.Session, plantNr int, userid string) *WeekModelDAOImplement {
	return &WeekModelDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) InsertOne(entity *model.WeekModel) (int, error) {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.WeekModel.TableName).Insert(entity)
	if err != nil {
		return 0, grmi.NewDataBaseError(err)
	}
	return entity.WeekModelNr, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) DeleteOne(weekModelNr int) error {
	_, err := impl.session.Table(meta.WeekModel.TableName).ID(core.PK{impl.plantNr, weekModelNr}).Delete(meta.WeekModel.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) SelectOne(weekModelNr int) (*model.WeekModel, error) {
	var data model.WeekModel
	ok, err := impl.session.Table(meta.WeekModel.TableName).ID(core.PK{impl.plantNr, weekModelNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) UpdateOne(entity *model.WeekModel) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.WeekModel.TableName).Cols(meta.WeekModel.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.Insert
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) Insert(entities *[]model.WeekModel) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.WeekModel.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.Delete
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) Delete(entities *[]model.WeekModel) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.WeekModel.TableName).ID(entity.GetKey()).Delete(meta.WeekModel.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WeekModel.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.WeekModel.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.Select
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WeekModel, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WeekModel.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WeekModel, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WeekModel.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.WeekModel.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WeekModel, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.WeekModel.TableName).SQL("select * from "+meta.WeekModel.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.Update
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) Update(entities *[]model.WeekModel) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.WeekModel.TableName).Cols(meta.WeekModel.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WeekModelDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WeekModelDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WeekModel, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WeekModel.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WeekModel_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.WeekModel.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
