// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/base"
	model "LAPP_GAAS_GFrame_BACKEND/models/base"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
*
* @Struct Name              : WorkCalendarDAOImplement
*-----------------------------------------------------------------------------
*
* @Description              : WorkCalendar的数据访问对象实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-24 09:53:49
*
******************************************************************************/
type WorkCalendarDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWorkCalendarDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkCalendarDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WorkCalendarDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-24 09:53:49
 *
 ******************************************************************************/
func NewWorkCalendarDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkCalendarDAOImplement {
	return &WorkCalendarDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) InsertOne(entity *model.WorkCalendar) (int, error) {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.WorkCalendar.TableName).Insert(entity)
	if err != nil {
		return 0, grmi.NewDataBaseError(err)
	}

	return entity.WorkCalendarNr, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) DeleteOne(workCalendarNr int) error {
	_, err := impl.session.Table(meta.WorkCalendar.TableName).ID(core.PK{impl.plantNr, workCalendarNr}).Delete(meta.WorkCalendar.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) SelectOne(workCalendarNr int) (*model.WorkCalendar, error) {
	var data model.WorkCalendar
	ok, err := impl.session.Table(meta.WorkCalendar.TableName).ID(core.PK{impl.plantNr, workCalendarNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) UpdateOne(entity *model.WorkCalendar) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.WorkCalendar.TableName).Cols(meta.WorkCalendar.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.Insert
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) Insert(entities *[]model.WorkCalendar) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.WorkCalendar.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.Delete
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) Delete(entities *[]model.WorkCalendar) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.WorkCalendar.TableName).ID(entity.GetKey()).Delete(meta.WorkCalendar.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WorkCalendar.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.WorkCalendar.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.Select
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkCalendar, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WorkCalendar.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WorkCalendar, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WorkCalendar.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.WorkCalendar.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkCalendar, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.WorkCalendar.TableName).SQL("select * from "+meta.WorkCalendar.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.Update
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) Update(entities *[]model.WorkCalendar) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.WorkCalendar.TableName).Cols(meta.WorkCalendar.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkCalendarDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WorkCalendarDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WorkCalendar, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WorkCalendar.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WorkCalendar_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.WorkCalendar.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
