// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/base"
	model "LAPP_GAAS_GFrame_BACKEND/models/base"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
*
* @Struct Name              : WorkLineDAOImplement
*-----------------------------------------------------------------------------
*
* @Description              : WorkLine的数据访问对象实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-24 09:53:49
*
******************************************************************************/
type WorkLineDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWorkLineDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkLineDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WorkLineDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-24 09:53:49
 *
 ******************************************************************************/
func NewWorkLineDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkLineDAOImplement {
	return &WorkLineDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) InsertOne(entity *model.WorkLine) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.WorkLine.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) DeleteOne(workLineid string) error {
	_, err := impl.session.Table(meta.WorkLine.TableName).ID(core.PK{impl.plantNr, workLineid}).Delete(meta.WorkLine.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) SelectOne(workLineid string) (*model.WorkLine, error) {
	var data model.WorkLine
	ok, err := impl.session.Table(meta.WorkLine.TableName).ID(core.PK{impl.plantNr, workLineid}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) UpdateOne(entity *model.WorkLine) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.WorkLine.TableName).Cols(meta.WorkLine.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.Insert
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) Insert(entities *[]model.WorkLine) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.WorkLine.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.Delete
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) Delete(entities *[]model.WorkLine) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.WorkLine.TableName).ID(entity.GetKey()).Delete(meta.WorkLine.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WorkLine.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.WorkLine.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.Select
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkLine, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WorkLine.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WorkLine, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WorkLine.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.WorkLine.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkLine, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.WorkLine.TableName).SQL("select * from "+meta.WorkLine.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.Update
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) Update(entities *[]model.WorkLine) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.WorkLine.TableName).Cols(meta.WorkLine.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/base/WorkLineDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WorkLine, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.WorkLine.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WorkLine_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.WorkLine.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
