// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/log"
	model "LAPP_GAAS_GFrame_BACKEND/models/log"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
*
* @Struct Name              : ArtDemandHeadDAOImplement
*-----------------------------------------------------------------------------
*
* @Description              : ArtDemandHead的数据访问对象实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-24 09:53:49
*
******************************************************************************/
type ArtDemandHeadDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewArtDemandHeadDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArtDemandHeadDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ArtDemandHeadDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-24 09:53:49
 *
 ******************************************************************************/
func NewArtDemandHeadDAOImplement(session *xorm.Session, plantNr int, userid string) *ArtDemandHeadDAOImplement {
	return &ArtDemandHeadDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) InsertOne(entity *model.ArtDemandHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.ArtDemandHead.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) DeleteOne(artId string, demandId string) error {
	_, err := impl.session.Table(meta.ArtDemandHead.TableName).ID(core.PK{impl.plantNr, artId, demandId}).Delete(meta.ArtDemandHead.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SelectOne(artId string, demandId string) (*model.ArtDemandHead, error) {
	var data model.ArtDemandHead
	ok, err := impl.session.Table(meta.ArtDemandHead.TableName).ID(core.PK{impl.plantNr, artId, demandId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) UpdateOne(entity *model.ArtDemandHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.ArtDemandHead.TableName).Cols(meta.ArtDemandHead.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.Insert
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) Insert(entities *[]model.ArtDemandHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.ArtDemandHead.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.Delete
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) Delete(entities *[]model.ArtDemandHead) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.ArtDemandHead.TableName).ID(entity.GetKey()).Delete(meta.ArtDemandHead.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ArtDemandHead.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.ArtDemandHead.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.Select
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandHead, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ArtDemandHead.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ArtDemandHead, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ArtDemandHead.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.ArtDemandHead.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArtDemandHead, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.ArtDemandHead.TableName).SQL("select * from "+meta.ArtDemandHead.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.Update
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) Update(entities *[]model.ArtDemandHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.ArtDemandHead.TableName).Cols(meta.ArtDemandHead.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandHeadDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ArtDemandHead, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ArtDemandHead.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ArtDemandHead_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.ArtDemandHead.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
