// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/log"
	model "LAPP_GAAS_GFrame_BACKEND/models/log"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
*
* @Struct Name              : ArtDemandLstDAOImplement
*-----------------------------------------------------------------------------
*
* @Description              : ArtDemandLst的数据访问对象实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-24 09:53:49
*
******************************************************************************/
type ArtDemandLstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewArtDemandLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArtDemandLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ArtDemandLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-24 09:53:49
 *
 ******************************************************************************/
func NewArtDemandLstDAOImplement(session *xorm.Session, plantNr int, userid string) *ArtDemandLstDAOImplement {
	return &ArtDemandLstDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) InsertOne(entity *model.ArtDemandLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.ArtDemandLst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) DeleteOne(artId string, demandTime grmi.DateTime) error {
	_, err := impl.session.Table(meta.ArtDemandLst.TableName).ID(core.PK{impl.plantNr, artId, demandTime.ToString()}).Delete(meta.ArtDemandLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) SelectOne(artId string, demandTime grmi.DateTime) (*model.ArtDemandLst, error) {
	var data model.ArtDemandLst
	ok, err := impl.session.Table(meta.ArtDemandLst.TableName).ID(core.PK{impl.plantNr, artId, demandTime.ToString()}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) UpdateOne(entity *model.ArtDemandLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.ArtDemandLst.TableName).Cols(meta.ArtDemandLst.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.Insert
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) Insert(entities *[]model.ArtDemandLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.ArtDemandLst.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.Delete
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) Delete(entities *[]model.ArtDemandLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.ArtDemandLst.TableName).ID(entity.GetKey()).Delete(meta.ArtDemandLst.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ArtDemandLst.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.ArtDemandLst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.Select
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ArtDemandLst.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ArtDemandLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ArtDemandLst.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.ArtDemandLst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArtDemandLst, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.ArtDemandLst.TableName).SQL("select * from "+meta.ArtDemandLst.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.Update
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) Update(entities *[]model.ArtDemandLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.ArtDemandLst.TableName).Cols(meta.ArtDemandLst.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ArtDemandLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ArtDemandLst.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ArtDemandLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.ArtDemandLst.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/ArtDemandLstDAO.DeleteByHead
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) DeleteByHead(records *[]model.ArtDemandItem) error {
	for _, item := range *records {
		_, err := impl.session.Table(meta.ArtDemandLst.TableName).Where("PlantNr = ? and ArtId = ? and DemandId = ?", impl.plantNr, item.ArtId, item.DemandId).Delete(impl)
		if err != nil {
			return err
		}
	}
	return nil
}
