// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/log"
	model "LAPP_GAAS_GFrame_BACKEND/models/log"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
*
* @Struct Name              : PackTemplateDAOImplement
*-----------------------------------------------------------------------------
*
* @Description              : PackTemplate的数据访问对象实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-24 09:53:49
*
******************************************************************************/
type PackTemplateDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewPackTemplateDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个PackTemplateDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : PackTemplateDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-24 09:53:49
 *
 ******************************************************************************/
func NewPackTemplateDAOImplement(session *xorm.Session, plantNr int, userid string) *PackTemplateDAOImplement {
	return &PackTemplateDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.InsertOne
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) InsertOne(entity *model.PackTemplate) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.PackTemplate.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) DeleteOne(packTemplateId string) error {
	_, err := impl.session.Table(meta.PackTemplate.TableName).ID(core.PK{impl.plantNr, packTemplateId}).Delete(meta.PackTemplate.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.SelectOne
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) SelectOne(packTemplateId string) (*model.PackTemplate, error) {
	var data model.PackTemplate
	ok, err := impl.session.Table(meta.PackTemplate.TableName).ID(core.PK{impl.plantNr, packTemplateId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) UpdateOne(entity *model.PackTemplate) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.PackTemplate.TableName).Cols(meta.PackTemplate.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.Insert
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) Insert(entities *[]model.PackTemplate) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.PackTemplate.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.Delete
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) Delete(entities *[]model.PackTemplate) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.PackTemplate.TableName).ID(entity.GetKey()).Delete(meta.PackTemplate.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.PackTemplate.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.PackTemplate.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.Select
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.PackTemplate, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.PackTemplate.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.PackTemplate, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.PackTemplate.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.PackTemplate.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.PackTemplate, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.PackTemplate.TableName).SQL("select * from "+meta.PackTemplate.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.Update
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) Update(entities *[]model.PackTemplate) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.PackTemplate.TableName).Cols(meta.PackTemplate.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/log/PackTemplateDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *PackTemplateDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.PackTemplate, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.PackTemplate.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.PackTemplate_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.PackTemplate.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
