// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/ods"
	model "LAPP_GAAS_GFrame_BACKEND/models/ods"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
*
* @Struct Name              : OdsHeadDAOImplement
*-----------------------------------------------------------------------------
*
* @Description              : OdsHead的数据访问对象实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-24 09:53:49
*
******************************************************************************/
type OdsHeadDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewOdsHeadDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个OdsHeadDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : OdsHeadDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-24 09:53:49
 *
 ******************************************************************************/
func NewOdsHeadDAOImplement(session *xorm.Session, plantNr int, userid string) *OdsHeadDAOImplement {
	return &OdsHeadDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.InsertOne
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) InsertOne(entity *model.OdsHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.OdsHead.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) DeleteOne(odsId string) error {
	_, err := impl.session.Table(meta.OdsHead.TableName).ID(core.PK{impl.plantNr, odsId}).Delete(meta.OdsHead.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.SelectOne
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) SelectOne(odsId string) (*model.OdsHead, error) {
	var data model.OdsHead
	ok, err := impl.session.Table(meta.OdsHead.TableName).ID(core.PK{impl.plantNr, odsId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) UpdateOne(entity *model.OdsHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.OdsHead.TableName).Cols(meta.OdsHead.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.Insert
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) Insert(entities *[]model.OdsHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.OdsHead.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.Delete
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) Delete(entities *[]model.OdsHead) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.OdsHead.TableName).ID(entity.GetKey()).Delete(meta.OdsHead.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.OdsHead.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.OdsHead.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.Select
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.OdsHead, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.OdsHead.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.OdsHead, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.OdsHead.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.OdsHead.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.OdsHead, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.OdsHead.TableName).SQL("select * from "+meta.OdsHead.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.Update
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) Update(entities *[]model.OdsHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.OdsHead.TableName).Cols(meta.OdsHead.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/ods/OdsHeadDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *OdsHeadDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.OdsHead, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.OdsHead.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.OdsHead_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.OdsHead.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
