// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/qm"
	model "LAPP_GAAS_GFrame_BACKEND/models/qm"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
*
* @Struct Name              : ViewValstDAOImplement
*-----------------------------------------------------------------------------
*
* @Description              : ViewValst的数据访问对象实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-24 09:53:49
*
******************************************************************************/
type ViewValstDAOImplement struct {
	session *xorm.Session
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewViewValstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ViewValstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ViewValstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-24 09:53:49
 *
 ******************************************************************************/
func NewViewValstDAOImplement(session *xorm.Session, plantNr int, userid string) *ViewValstDAOImplement {
	return &ViewValstDAOImplement{session, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) InsertOne(entity *model.ViewValst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.ViewValst.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) DeleteOne(viewId string, pos int) error {
	_, err := impl.session.Table(meta.ViewValst.TableName).ID(core.PK{impl.plantNr, viewId, pos}).Delete(meta.ViewValst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) SelectOne(viewId string, pos int) (*model.ViewValst, error) {
	var data model.ViewValst
	ok, err := impl.session.Table(meta.ViewValst.TableName).ID(core.PK{impl.plantNr, viewId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) UpdateOne(entity *model.ViewValst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.ViewValst.TableName).Cols(meta.ViewValst.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.Insert
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) Insert(entities *[]model.ViewValst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(meta.ViewValst.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.Delete
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) Delete(entities *[]model.ViewValst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(meta.ViewValst.TableName).ID(entity.GetKey()).Delete(meta.ViewValst.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ViewValst.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(meta.ViewValst.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.Select
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ViewValst, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ViewValst.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy("PlantNr")
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ViewValst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ViewValst.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(meta.ViewValst.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by PlantNr"
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ViewValst, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(meta.ViewValst.TableName).SQL("select * from "+meta.ViewValst.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.Update
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) Update(entities *[]model.ViewValst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(meta.ViewValst.TableName).Cols(meta.ViewValst.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/dao/qm/ViewValstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ViewValstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ViewValst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := "PlantNr = ?"

	session := impl.session.Table(meta.ViewValst.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ViewValst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(meta.ViewValst.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
