package rpc

import (
	"LAPP_GAAS_GFrame_BACKEND/web/models"
	"errors"
	"fmt"
	"github.com/kataras/iris/v12/core/router"
	"reflect"
)

var contextType = reflect.TypeOf((*models.Usertab)(nil))
var errorType = reflect.TypeOf((*error)(nil)).Elem()

type MethodInvokerBuilder struct {
	valueParserBuilder *ValueParserBuilder
}

func (builder *MethodInvokerBuilder) checkOutType(parameterType reflect.Type) (bool, string) {
	switch parameterType.Kind() {
	case reflect.Invalid:
		return false, parameterType.Name()
	case reflect.Bool:
		return true, parameterType.Name()
	case reflect.Int:
		return true, parameterType.Name()
	case reflect.Int8:
		return true, parameterType.Name()
	case reflect.Int16:
		return true, parameterType.Name()
	case reflect.Int32:
		return true, parameterType.Name()
	case reflect.Int64:
		return true, parameterType.Name()
	case reflect.Uint:
		return true, parameterType.Name()
	case reflect.Uint8:
		return true, parameterType.Name()
	case reflect.Uint16:
		return true, parameterType.Name()
	case reflect.Uint32:
		return true, parameterType.Name()
	case reflect.Uint64:
		return true, parameterType.Name()
	case reflect.Uintptr:
		return false, parameterType.Name()
	case reflect.Float32:
		return true, parameterType.Name()
	case reflect.Float64:
		return true, parameterType.Name()
	case reflect.Complex64:
		return false, parameterType.Name()
	case reflect.Complex128:
		return false, parameterType.Name()
	case reflect.Array:
		if ok, typeText := builder.checkOutType(parameterType.Elem()); ok {
			return true, fmt.Sprintf("[%d]%s", parameterType.Len(), typeText)
		} else {
			return false, fmt.Sprintf("[%d]%s", parameterType.Len(), typeText)
		}
	case reflect.Chan:
		return false, parameterType.Name()
	case reflect.Func:
		return false, parameterType.Name()
	case reflect.Interface:
		return true, getFullName(parameterType)
	case reflect.Map:
		keyOk, keyTypeText := builder.checkOutType(parameterType.Key())
		valueOk, valueTypeText := builder.checkOutType(parameterType.Elem())
		if keyOk && valueOk {
			return true, fmt.Sprintf("*map[%s]%s", keyTypeText, valueTypeText)
		} else {
			return false, fmt.Sprintf("*map[%s]%s", keyTypeText, valueTypeText)
		}
	case reflect.Ptr:
		if ok, typeText := builder.checkOutType(parameterType.Elem()); ok {
			return true, fmt.Sprintf("*%s", typeText)
		} else {
			return false, fmt.Sprintf("*%s", typeText)
		}
	case reflect.Slice:
		if ok, typeText := builder.checkOutType(parameterType.Elem()); ok {
			return true, fmt.Sprintf("[]%s", typeText)
		} else {
			return false, fmt.Sprintf("[]%s", typeText)
		}
	case reflect.String:
		return true, parameterType.Name()
	case reflect.Struct:
		return true, getFullName(parameterType)
	case reflect.UnsafePointer:
		return false, parameterType.Name()
	default:
		return false, "Unknown"
	}
}

func (builder *MethodInvokerBuilder) BuildParameterParsers(path string, methodType reflect.Type) ([]valueParser, error) {

	if methodType.NumIn() < 1 {
		return nil, errors.New(fmt.Sprintf("参数数量错误! Path: %s 参数数量: %d", path, methodType.NumIn()))
	}
	if methodType.In(0) != contextType {
		return nil, errors.New(fmt.Sprintf("第一个参数类型错误! Path: %s 类型:%s", path, methodType.In(0)))
	}
	parameterParsers := make([]valueParser, 0, 10)
	for i := 1; i < methodType.NumIn(); i++ {
		if parameterParser, err := builder.valueParserBuilder.Build(fmt.Sprintf("%s-in#%d", path, i), methodType.In(i)); err != nil {
			return nil, err
		} else {
			parameterParsers = append(parameterParsers, parameterParser)
		}
	}
	if methodType.NumOut() < 1 || 2 < methodType.NumOut() {
		return nil, errors.New(fmt.Sprintf("返回值数量错误! Path: %s 返回值数量: %d", path, methodType.NumOut()))
	}
	if methodType.Out(methodType.NumOut()-1) != errorType {
		return nil, errors.New(fmt.Sprintf("最后一个返回值类型错误! Path: %s 类型:%s", path, methodType.Out(methodType.NumOut()-1)))
	}
	for i := 0; i < methodType.NumOut(); i++ {
		if ok, typeText := builder.checkOutType(methodType.Out(i)); !ok {
			return nil, errors.New(fmt.Sprintf("不支持的返回值类型! Path:%s 参数: #%d 类型: %s", path, i+1, typeText))
		}
	}
	return parameterParsers, nil
}

func (builder *MethodInvokerBuilder) Register(party router.Party, path string, methodType reflect.Type, call func([]reflect.Value) []reflect.Value) error {

	parameterParsers, err := builder.BuildParameterParsers(path, methodType)
	if err != nil {
		return err
	}
	RegisterHandler(party, path, NewMethodInvoker(call, parameterParsers))
	return nil
}
