// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package rpc

import (
	"LAPP_GAAS_GFrame_BACKEND/web/middleware/jwts"
	"LAPP_GAAS_GFrame_BACKEND/web/supports"
	"fmt"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	"reflect"
)

type valueParser func(interface{}, string) (interface{}, error)

var DefaultMethodInvokerBuilder = &MethodInvokerBuilder{&ValueParserBuilder{}}

func getFullName(t reflect.Type) string {
	if "" == t.PkgPath() {
		return t.Name()
	} else {
		return fmt.Sprintf("%s.%s", t.PkgPath(), t.Name())
	}
}

func RegisterHandler(party router.Party, path string, handler Handler) {
	party.Post(path, func(context iris.Context) {
		var json interface{}
		var jsonArray []interface{}
		if context.GetContentLength() > 0 {
			if nil != context.ReadJSON(&json) {
				supports.Error(context, iris.StatusBadRequest, "JSON解析失败!", nil)
				return
			}
			if json != nil {
				if jsonObject, ok := json.([]interface{}); !ok {
					supports.Error(context, iris.StatusBadRequest, "JSON解析失败!", nil)
					return
				} else {
					jsonArray = jsonObject
				}
			}
		}
		user, ok := jwts.ParseToken(context)
		if !ok {
			supports.Error(context, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		if result, err := handler.Process(user, jsonArray); err != nil {
			supports.Error(context, iris.StatusBadRequest, err.Error(), nil)
		} else {
			supports.Ok(context, supports.OptionSuccess, result)
		}
	})
}
