// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_GAAS_GFrame_BACKEND/dao/base"
	"LAPP_GAAS_GFrame_BACKEND/db"
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/base"
	model "LAPP_GAAS_GFrame_BACKEND/models/base"
	"LAPP_GAAS_GFrame_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Description              : WorkLine的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
var DefaultConditionOfWorkLine = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkLine_WorkLineid.UrlParameterName:              grmi.NewConditionItem(meta.WorkLine_WorkLineid, grmi.Equal, true),
		meta.WorkLine_Descr.UrlParameterName:                   grmi.NewConditionItem(meta.WorkLine_Descr, grmi.Equal, false),
		meta.WorkLine_LineType.UrlParameterName:                grmi.NewConditionItem(meta.WorkLine_LineType, grmi.Equal, false),
		meta.WorkLine_LinePlanMode.UrlParameterName:            grmi.NewConditionItem(meta.WorkLine_LinePlanMode, grmi.Equal, false),
		meta.WorkLine_WeekModelNr.UrlParameterName:             grmi.NewConditionItem(meta.WorkLine_WeekModelNr, grmi.Equal, false),
		meta.WorkLine_WorkCalendarNr.UrlParameterName:          grmi.NewConditionItem(meta.WorkLine_WorkCalendarNr, grmi.Equal, false),
		meta.WorkLine_Location.UrlParameterName:                grmi.NewConditionItem(meta.WorkLine_Location, grmi.Equal, false),
		meta.WorkLine_CostCenterId.UrlParameterName:            grmi.NewConditionItem(meta.WorkLine_CostCenterId, grmi.Equal, false),
		meta.WorkLine_CostRate.UrlParameterName:                grmi.NewConditionItem(meta.WorkLine_CostRate, grmi.Equal, false),
		meta.WorkLine_ProdEff.UrlParameterName:                 grmi.NewConditionItem(meta.WorkLine_ProdEff, grmi.Equal, false),
		meta.WorkLine_ReqWorkers.UrlParameterName:              grmi.NewConditionItem(meta.WorkLine_ReqWorkers, grmi.Equal, false),
		meta.WorkLine_Pos.UrlParameterName:                     grmi.NewConditionItem(meta.WorkLine_Pos, grmi.Equal, false),
		meta.WorkLine_TaskQueueSortWay.UrlParameterName:        grmi.NewConditionItem(meta.WorkLine_TaskQueueSortWay, grmi.Equal, false),
		meta.WorkLine_MultiQueueMixSortToggle.UrlParameterName: grmi.NewConditionItem(meta.WorkLine_MultiQueueMixSortToggle, grmi.Equal, false),
		meta.WorkLine_TaskQueueMixSortWay.UrlParameterName:     grmi.NewConditionItem(meta.WorkLine_TaskQueueMixSortWay, grmi.Equal, false),
		meta.WorkLine_MixSortLogic.UrlParameterName:            grmi.NewConditionItem(meta.WorkLine_MixSortLogic, grmi.Equal, false),
		meta.WorkLine_TaskReleaseWay.UrlParameterName:          grmi.NewConditionItem(meta.WorkLine_TaskReleaseWay, grmi.Equal, false),
		meta.WorkLine_ReleaseQtyParameter.UrlParameterName:     grmi.NewConditionItem(meta.WorkLine_ReleaseQtyParameter, grmi.Equal, false),
		meta.WorkLine_ReleaseTimeParameter.UrlParameterName:    grmi.NewConditionItem(meta.WorkLine_ReleaseTimeParameter, grmi.Approximate, false),
		meta.WorkLine_ReleaseCtrlParameter.UrlParameterName:    grmi.NewConditionItem(meta.WorkLine_ReleaseCtrlParameter, grmi.Equal, false),
		meta.WorkLine_LastModify.UrlParameterName:              grmi.NewConditionItem(meta.WorkLine_LastModify, grmi.Approximate, false),
		meta.WorkLine_LastUser.UrlParameterName:                grmi.NewConditionItem(meta.WorkLine_LastUser, grmi.Equal, false),
		meta.WorkLine_CreateTime.UrlParameterName:              grmi.NewConditionItem(meta.WorkLine_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WorkLine的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
var DefaultConditionOfWorkLineAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkLine.Items,
	grmi.NewPaging(),
)

/******************************************************************************
*
* @Struct Name              : WorkLineServiceImplement
*-----------------------------------------------------------------------------
*
* @Description              : WorkLine的服务实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-23 10:43:27
*
******************************************************************************/
type WorkLineServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWorkLineDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkLineDAOImplement实例
 *
 * @Return Value             : WorkLineDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
func NewWorkLineServiceImplement() *WorkLineServiceImplement {
	return &WorkLineServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/base/WorkLineService.InsertOne
 *
 ******************************************************************************/
func (impl *WorkLineServiceImplement) InsertOne(user *models.Usertab, entity *model.WorkLine) error {

	grmi.Log(user, "/services/base/implments/WorkLine.service.impl.go", "InsertOneWorkLine", "插入一个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineid)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	weekModelDao := dal.NewWeekModelDAO(session, user.Pid, user.Userid)
	weekModel, err := weekModelDao.SelectOne(entity.WeekModelNr)
	if err != nil {
		return err
	}
	if weekModel == nil {
		return grmi.NewBusinessError("不存在对应的周模型，请检查")
	}
	if entity.WorkCalendarNr != 0 {
		calendarDao := dal.NewWorkCalendarDAO(session, user.Pid, user.Userid)
		calendar, err := calendarDao.SelectOne(entity.WorkCalendarNr)
		if err != nil {
			return err
		}
		if calendar == nil {
			return grmi.NewBusinessError("不存在对应的日历模型")
		}
	}

	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/base/WorkLineService.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkLineServiceImplement) DeleteOne(user *models.Usertab, workLineid string) error {

	grmi.Log(user, "/services/base/implments/WorkLine.service.impl.go", "DeleteOneWorkLine", "删除一个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	err := session.Begin()
	if err != nil {
		return err
	}
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workLineid)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	specialDayDao := dal.NewWorkLineSpecialDayDAO(session, user.Pid, user.Userid)
	err = specialDayDao.DeleteWhere([]grmi.Predicate{meta.WorkLineSpecialDay_WorkLineid.NewPredicate(grmi.Equal, workLineid)})
	if err != nil {
		session.Rollback()
		return err
	}
	workLineShiftDao := dal.NewWorkLineWorkShiftLstDAO(session, user.Pid, user.Userid)
	err = workLineShiftDao.DeleteWhere([]grmi.Predicate{meta.WorkLineWorkShiftLst_WorkLineId.NewPredicate(grmi.Equal, workLineid)})
	if err != nil {
		session.Rollback()
		return err
	}
	err = dao.DeleteOne(workLineid)
	if err != nil {
		session.Rollback()
		return err
	}
	session.Commit()
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/base/WorkLineService.SelectOne
 *
 ******************************************************************************/
func (impl *WorkLineServiceImplement) SelectOne(user *models.Usertab, workLineid string) (*model.WorkLine, error) {

	grmi.Log(user, "/services/base/implments/WorkLine.service.impl.go", "SelectOneWorkLine", "查询一个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workLineid)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/base/WorkLineService.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkLineServiceImplement) UpdateOne(user *models.Usertab, entity *model.WorkLine) error {

	grmi.Log(user, "/services/base/implments/WorkLine.service.impl.go", "UpdateOneWorkLine", "修改一个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineid)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	if record.WeekModelNr != entity.WeekModelNr {
		weekModelDao := dal.NewWeekModelDAO(session, user.Pid, user.Userid)
		weekModel, err := weekModelDao.SelectOne(entity.WeekModelNr)
		if err != nil {
			return err
		}
		if weekModel == nil {
			return grmi.NewBusinessError("不存在对应的周模型，请检查")
		}
	}
	if record.WorkCalendarNr != entity.WorkCalendarNr && entity.WorkCalendarNr != 0 {
		calendarDao := dal.NewWorkCalendarDAO(session, user.Pid, user.Userid)
		calendar, err := calendarDao.SelectOne(entity.WorkCalendarNr)
		if err != nil {
			return err
		}
		if calendar == nil {
			return grmi.NewBusinessError("不存在对应的日历模型，请检查")
		}
	}
	entity.WorkLineid = record.WorkLineid
	entity.Pos = record.Pos
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/base/WorkLineService.Insert
 *
 ******************************************************************************/
func (impl *WorkLineServiceImplement) Insert(user *models.Usertab, entities *[]model.WorkLine) error {

	grmi.Log(user, "/services/base/implments/WorkLine.service.impl.go", "InsertWorkLine", "插入多个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkLineid)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/base/WorkLineService.Delete
 *
 ******************************************************************************/
func (impl *WorkLineServiceImplement) Delete(user *models.Usertab, entities *[]model.WorkLine) error {

	grmi.Log(user, "/services/base/implments/WorkLine.service.impl.go", "DeleteWorkLine", "删除多个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkLineid)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/base/WorkLineService.Select
 *
 ******************************************************************************/
func (impl *WorkLineServiceImplement) Select(user *models.Usertab, urlParameters map[string]string) (interface{}, error) {

	grmi.Log(user, "/services/base/implments/WorkLine.service.impl.go", "SelectWorkLine", "查询WorkLine")

	condition := DefaultConditionOfWorkLineAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/base/WorkLineService.Update
 *
 ******************************************************************************/
func (impl *WorkLineServiceImplement) Update(user *models.Usertab, entities *[]model.WorkLine) error {

	grmi.Log(user, "/services/base/implments/WorkLine.service.impl.go", "UpdateWorkLine", "修改多个WorkLine")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkLineid)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
