// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	baseDal "LAPP_GAAS_GFrame_BACKEND/dao/base"
	dal "LAPP_GAAS_GFrame_BACKEND/dao/log"
	"LAPP_GAAS_GFrame_BACKEND/db"
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/log"
	model "LAPP_GAAS_GFrame_BACKEND/models/log"
	"LAPP_GAAS_GFrame_BACKEND/utils"
	"LAPP_GAAS_GFrame_BACKEND/web/models"
	"errors"
	"fmt"
	"strconv"
	"time"
)

/******************************************************************************
 *
 * @Description              : ArtDemandLst的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
var DefaultConditionOfArtDemandLst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ArtDemandLst_ArtId.UrlParameterName:              grmi.NewConditionItem(meta.ArtDemandLst_ArtId, grmi.Equal, true),
		meta.ArtDemandLst_DemandTime.UrlParameterName:         grmi.NewConditionItem(meta.ArtDemandLst_DemandTime, grmi.Approximate, true),
		meta.ArtDemandLst_DemandId.UrlParameterName:           grmi.NewConditionItem(meta.ArtDemandLst_DemandId, grmi.Equal, false),
		meta.ArtDemandLst_DemandYear.UrlParameterName:         grmi.NewConditionItem(meta.ArtDemandLst_DemandYear, grmi.Equal, false),
		meta.ArtDemandLst_DemandMonth.UrlParameterName:        grmi.NewConditionItem(meta.ArtDemandLst_DemandMonth, grmi.Equal, false),
		meta.ArtDemandLst_DemandWeek.UrlParameterName:         grmi.NewConditionItem(meta.ArtDemandLst_DemandWeek, grmi.Equal, false),
		meta.ArtDemandLst_DemandDate.UrlParameterName:         grmi.NewConditionItem(meta.ArtDemandLst_DemandDate, grmi.Approximate, false),
		meta.ArtDemandLst_DemandHour.UrlParameterName:         grmi.NewConditionItem(meta.ArtDemandLst_DemandHour, grmi.Equal, false),
		meta.ArtDemandLst_DemandQty.UrlParameterName:          grmi.NewConditionItem(meta.ArtDemandLst_DemandQty, grmi.Equal, false),
		meta.ArtDemandLst_QtyUomId.UrlParameterName:           grmi.NewConditionItem(meta.ArtDemandLst_QtyUomId, grmi.Equal, false),
		meta.ArtDemandLst_DemandObjId.UrlParameterName:        grmi.NewConditionItem(meta.ArtDemandLst_DemandObjId, grmi.Equal, false),
		meta.ArtDemandLst_DemandType.UrlParameterName:         grmi.NewConditionItem(meta.ArtDemandLst_DemandType, grmi.Equal, false),
		meta.ArtDemandLst_Status.UrlParameterName:             grmi.NewConditionItem(meta.ArtDemandLst_Status, grmi.Equal, false),
		meta.ArtDemandLst_DemandSendTime.UrlParameterName:     grmi.NewConditionItem(meta.ArtDemandLst_DemandSendTime, grmi.Approximate, false),
		meta.ArtDemandLst_DemandRecieveTime.UrlParameterName:  grmi.NewConditionItem(meta.ArtDemandLst_DemandRecieveTime, grmi.Approximate, false),
		meta.ArtDemandLst_DemandConfirmTime.UrlParameterName:  grmi.NewConditionItem(meta.ArtDemandLst_DemandConfirmTime, grmi.Approximate, false),
		meta.ArtDemandLst_DemandCloseTime.UrlParameterName:    grmi.NewConditionItem(meta.ArtDemandLst_DemandCloseTime, grmi.Approximate, false),
		meta.ArtDemandLst_DemandDeliveredQty.UrlParameterName: grmi.NewConditionItem(meta.ArtDemandLst_DemandDeliveredQty, grmi.Equal, false),
		meta.ArtDemandLst_DemandCtrlPara1.UrlParameterName:    grmi.NewConditionItem(meta.ArtDemandLst_DemandCtrlPara1, grmi.Equal, false),
		meta.ArtDemandLst_DemandCtrlPara2.UrlParameterName:    grmi.NewConditionItem(meta.ArtDemandLst_DemandCtrlPara2, grmi.Equal, false),
		meta.ArtDemandLst_DemandCtrlPara3.UrlParameterName:    grmi.NewConditionItem(meta.ArtDemandLst_DemandCtrlPara3, grmi.Equal, false),
		meta.ArtDemandLst_DemandCtrlPara4.UrlParameterName:    grmi.NewConditionItem(meta.ArtDemandLst_DemandCtrlPara4, grmi.Equal, false),
		meta.ArtDemandLst_DemandCtrlTime1.UrlParameterName:    grmi.NewConditionItem(meta.ArtDemandLst_DemandCtrlTime1, grmi.Approximate, false),
		meta.ArtDemandLst_DemandCtrlTime2.UrlParameterName:    grmi.NewConditionItem(meta.ArtDemandLst_DemandCtrlTime2, grmi.Approximate, false),
		meta.ArtDemandLst_LastModify.UrlParameterName:         grmi.NewConditionItem(meta.ArtDemandLst_LastModify, grmi.Approximate, false),
		meta.ArtDemandLst_LastUser.UrlParameterName:           grmi.NewConditionItem(meta.ArtDemandLst_LastUser, grmi.Equal, false),
		meta.ArtDemandLst_CreateTime.UrlParameterName:         grmi.NewConditionItem(meta.ArtDemandLst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : ArtDemandLst的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
var DefaultConditionOfArtDemandLstAndPaging = grmi.NewCondition(
	DefaultConditionOfArtDemandLst.Items,
	grmi.NewPaging(),
)

/******************************************************************************
*
* @Struct Name              : ArtDemandLstServiceImplement
*-----------------------------------------------------------------------------
*
* @Description              : ArtDemandLst的服务实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-23 10:43:27
*
******************************************************************************/
type ArtDemandLstServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewArtDemandLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArtDemandLstDAOImplement实例
 *
 * @Return Value             : ArtDemandLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
func NewArtDemandLstServiceImplement() *ArtDemandLstServiceImplement {
	return &ArtDemandLstServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.InsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) InsertOne(user *models.Usertab, entity *model.ArtDemandLst) error {

	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "InsertOneArtDemandLst", "插入一个ArtDemandLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	//headDao := dal.NewArtDemandHeadDAO(session, user.Pid, user.Userid)
	//headItem, err := headDao.SelectOne(entity.ArtId, entity.DemandId)
	//if err != nil {
	//	return err
	//}
	//if headItem == nil {
	//	return grmi.NewBusinessError("对应的artDemandHead不存在，请检查")
	//}
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId, entity.DemandTime)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	baseDao := baseDal.NewArticleDAO(session, user.Pid, user.Userid)
	article, err := baseDao.SelectOne(entity.ArtId)
	if err != nil {
		return err
	}
	if article == nil {
		return grmi.NewBusinessError("不存在对应的物料，请检查")
	}
	demandTime := entity.DemandTime.Restore()
	entity.DemandYear = demandTime.Year()
	entity.DemandMonth = int(demandTime.Month())
	entity.DemandWeek = int(demandTime.Weekday())
	entity.DemandSendTime = grmi.DateTime(time.Now())
	entity.DemandHour = demandTime.Hour()
	entity.DemandDate = grmi.Date(demandTime)
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.DeleteOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) DeleteOne(user *models.Usertab, artId string, demandTime grmi.DateTime) error {

	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "DeleteOneArtDemandLst", "删除一个ArtDemandLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(artId, demandTime)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(artId, demandTime)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.SelectOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) SelectOne(user *models.Usertab, artId string, demandTime grmi.DateTime) (*model.ArtDemandLst, error) {

	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "SelectOneArtDemandLst", "查询一个ArtDemandLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(artId, demandTime)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.UpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) UpdateOne(user *models.Usertab, entity *model.ArtDemandLst) error {

	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "UpdateOneArtDemandLst", "修改一个ArtDemandLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ArtId, entity.DemandTime)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	record.DemandId = entity.DemandId
	record.DemandCtrlPara1 = entity.DemandCtrlPara1
	record.DemandCtrlPara2 = entity.DemandCtrlPara2
	record.DemandCtrlPara3 = entity.DemandCtrlPara3
	record.DemandCtrlPara4 = entity.DemandCtrlPara4
	record.DemandCtrlTime1 = entity.DemandCtrlTime1
	record.DemandCtrlTime2 = entity.DemandCtrlTime2
	record.DemandObjId = entity.DemandObjId
	record.DemandDeliveredQty = entity.DemandDeliveredQty
	record.DemandQty = entity.DemandQty
	record.QtyUomId = entity.QtyUomId
	record.DemandType = entity.DemandType
	err = dao.UpdateOne(record)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.Insert
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) Insert(user *models.Usertab, entities *[]model.ArtDemandLst) error {

	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "InsertArtDemandLst", "插入多个ArtDemandLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	err := session.Begin()
	if err != nil {
		return err
	}
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId, entity.DemandTime)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
		demandTime := entity.DemandTime.Restore()
		entity.DemandYear = demandTime.Year()
		entity.DemandMonth = int(demandTime.Month())
		entity.DemandWeek = int(demandTime.Weekday())
		entity.DemandSendTime = grmi.DateTime(time.Now())
		entity.DemandHour = demandTime.Hour()
		entity.DemandDate = grmi.Date(demandTime)
	}

	err = dao.Insert(entities)
	if err != nil {
		session.Rollback()
		return err
	}
	err = session.Commit()
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.Delete
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) Delete(user *models.Usertab, entities *[]model.ArtDemandLst) error {

	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "DeleteArtDemandLst", "删除多个ArtDemandLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	err := session.Begin()
	if err != nil {
		return err
	}
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId, entity.DemandTime)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err = dao.Delete(entities)
	if err != nil {
		session.Rollback()
		return err
	}
	err = session.Commit()
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.Select
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) Select(user *models.Usertab, urlParameters map[string]string) (interface{}, error) {

	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "SelectArtDemandLst", "查询ArtDemandLst")

	condition := DefaultConditionOfArtDemandLstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	grmi.DeleteUrlParametersEmpty(&urlParameters)
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	search, exist := urlParameters["search"]
	if exist {
		params := map[string]string{
			meta.ArtDemandLst_DemandId.UrlParameterName: search,
		}
		innerPredicates, err := condition.BuildPredicates(params)
		if err != nil {
			return nil, err
		}
		predicates = append(predicates, innerPredicates...)
	}
	urgencyString, exist := urlParameters["urgency"]
	if exist {
		urgency, err := strconv.Atoi(urgencyString)
		if err == nil {
			now := time.Now()
			date := now.AddDate(0, 0, 2)
			dateString := date.Format(grmi.DateOutFormat)
			today := now.Format(grmi.DateOutFormat)
			status, exist := urlParameters["status"]
			if exist && status == strconv.Itoa(model.AccomplishedStatus) {
				if urgency != model.UrgencyNot {
					predicate := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.Include)}
					predicates = append(predicates, predicate...)
				}
			} else {
				if urgency == model.UrgencyNot {
					predicate := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.GreaterThen, dateString)}
					predicates = append(predicates, predicate...)
				} else if urgency == model.UrgencyNormal {
					predicate1 := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.GreaterOrEqual, today)}
					predicate2 := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.LessOrEqual, dateString)}
					predicates = append(predicates, predicate1...)
					predicates = append(predicates, predicate2...)
				} else {
					predicate := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.LessThen, today)}
					predicates = append(predicates, predicate...)
				}
				predicate := []grmi.Predicate{meta.ArtDemandLst_Status.NewPredicate(grmi.NotEqual, model.AccomplishedStatus)}
				predicates = append(predicates, predicate...)
			}
		}

	}
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)
	year, month, day := time.Now().Date()
	var today time.Time
	var monthStr string
	var dayStr string
	if int(month) >= 10 {
		monthStr = strconv.Itoa(int(month))
	} else {
		monthStr = fmt.Sprintf("0%d", int(month))
	}
	if day >= 10 {
		dayStr = strconv.Itoa(day)
	} else {
		dayStr = fmt.Sprintf("0%d", day)
	}
	today, err = time.ParseInLocation(grmi.DateOutFormat, fmt.Sprintf("%d-%s-%s", year, monthStr, dayStr), utils.TimezoneLocation)
	if err != nil {
		return nil, err
	}
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		artDemandLstLi := result.Records.([]model.ArtDemandLst)
		baseDao := baseDal.NewArticleDAO(session, user.Pid, user.Userid)
		responseLi := make([]model.ArtDemandLstResponseItem, 0, len(artDemandLstLi))

		for _, artDemandLst := range artDemandLstLi {
			data := artDemandLst
			var responseItem model.ArtDemandLstResponseItem
			responseItem.ArtDemandLst = &data
			article, err := baseDao.SelectOne(artDemandLst.ArtId)
			if err != nil {
				return nil, err
			}
			if article != nil {
				responseItem.ArtDesc = article.Descr1
			}
			if artDemandLst.Status == model.AccomplishedStatus {
				responseItem.UrgencyDegree = 0
				responseItem.SurplusDays = 0
			} else {
				demandDate := artDemandLst.DemandDate.Restore()
				days := (demandDate.Unix() - today.Unix()) / 86400
				responseItem.SurplusDays = days
				if days > 2 {
					responseItem.UrgencyDegree = model.UrgencyNot
				} else if days >= 0 && days <= 2 {
					responseItem.UrgencyDegree = model.UrgencyNormal
				} else {
					responseItem.UrgencyDegree = model.UrgencySerious
				}
			}

			responseLi = append(responseLi, responseItem)
		}
		result.Records = responseLi
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		baseDao := baseDal.NewArticleDAO(session, user.Pid, user.Userid)
		responseLi := make([]model.ArtDemandLstResponseItem, 0, len(result))
		for _, artDemandLst := range result {
			data := artDemandLst
			var responseItem model.ArtDemandLstResponseItem
			responseItem.ArtDemandLst = &data
			article, err := baseDao.SelectOne(artDemandLst.ArtId)
			if err != nil {
				return nil, err
			}
			if article != nil {
				responseItem.ArtDesc = article.Descr1
			}
			if artDemandLst.Status == model.AccomplishedStatus {
				responseItem.UrgencyDegree = 0
				responseItem.SurplusDays = 0
			} else {
				demandDate := artDemandLst.DemandDate.Restore()

				days := (demandDate.Unix() - today.Unix()) / 86400
				responseItem.SurplusDays = days
				if days > 2 {
					responseItem.UrgencyDegree = model.UrgencyNot
				} else if days >= 0 && days <= 2 {
					responseItem.UrgencyDegree = model.UrgencyNormal
				} else {
					responseItem.UrgencyDegree = model.UrgencySerious
				}
			}
			responseLi = append(responseLi, responseItem)
		}
		return responseLi, nil
	}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.Update
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) Update(user *models.Usertab, entities *[]model.ArtDemandLst) error {

	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "UpdateArtDemandLst", "修改多个ArtDemandLst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	err := session.Begin()
	if err != nil {
		return err
	}
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ArtId, entity.DemandTime)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err = dao.Update(entities)
	if err != nil {
		session.Rollback()
		return err
	}
	err = session.Commit()
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.ExportExcel
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) ExportExcel(user *models.Usertab, urlParameters map[string]string) (interface{}, error) {
	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "ExportExcelArtDemandLst", "导出ArtDemandLst报表")
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	condition := DefaultConditionOfArtDemandLstAndPaging
	grmi.DeleteUrlParametersEmpty(&urlParameters)
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	search, exist := urlParameters["search"]
	if exist {
		params := map[string]string{
			meta.ArtDemandLst_DemandId.UrlParameterName: search,
		}
		innerPredicates, err := condition.BuildPredicates(params)
		if err != nil {
			return nil, err
		}
		predicates = append(predicates, innerPredicates...)
	}
	urgencyString, exist := urlParameters["urgency"]
	if exist {
		urgency, err := strconv.Atoi(urgencyString)
		if err == nil {
			now := time.Now()
			date := now.AddDate(0, 0, 2)
			dateString := date.Format(grmi.DateOutFormat)
			today := now.Format(grmi.DateOutFormat)
			status, exist := urlParameters["status"]
			if exist && status == strconv.Itoa(model.AccomplishedStatus) {
				if urgency != model.UrgencyNot {
					predicate := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.Include)}
					predicates = append(predicates, predicate...)
				}
			} else {
				if urgency == model.UrgencyNot {
					predicate := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.GreaterThen, dateString)}
					predicates = append(predicates, predicate...)
				} else if urgency == model.UrgencyNormal {
					predicate1 := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.GreaterOrEqual, today)}
					predicate2 := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.LessOrEqual, dateString)}
					predicates = append(predicates, predicate1...)
					predicates = append(predicates, predicate2...)
				} else {
					predicate := []grmi.Predicate{meta.ArtDemandLst_DemandDate.NewPredicate(grmi.LessThen, today)}
					predicates = append(predicates, predicate...)
				}
				predicate := []grmi.Predicate{meta.ArtDemandLst_Status.NewPredicate(grmi.NotEqual, model.AccomplishedStatus)}
				predicates = append(predicates, predicate...)
			}
		}

	}
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)
	year, month, day := time.Now().Date()
	var today time.Time
	var monthStr string
	var dayStr string
	if int(month) >= 10 {
		monthStr = strconv.Itoa(int(month))
	} else {
		monthStr = fmt.Sprintf("0%d", int(month))
	}
	if day >= 10 {
		dayStr = strconv.Itoa(day)
	} else {
		dayStr = fmt.Sprintf("0%d", day)
	}
	today, err = time.ParseInLocation(grmi.DateOutFormat, fmt.Sprintf("%d-%s-%s", year, monthStr, dayStr), utils.TimezoneLocation)
	if err != nil {
		return nil, err
	}
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	baseDao := baseDal.NewArticleDAO(session, user.Pid, user.Userid)
	responseLi := make([]model.ArtDemandLstResponseItemTemp, 0, len(result))
	for _, artDemandLst := range result {
		data := artDemandLst
		var responseItem model.ArtDemandLstResponseItemTemp
		if data.Status == model.ReceivedStatus {
			responseItem.Status = "接收"
		} else if data.Status == model.WaitReceivingStatus {
			responseItem.Status = "未接收"
		} else if data.Status == model.ConfirmedStatus {
			responseItem.Status = "确认交期"
		} else if data.Status == model.AccomplishedStatus{
			responseItem.Status = "完成答复"
		}
		responseItem.DemandDate = data.DemandDate
		responseItem.ArtId = data.ArtId
		responseItem.DemandTime = data.DemandTime
		responseItem.DemandType = data.DemandType
		responseItem.QtyUomId = data.QtyUomId
		responseItem.DemandDeliveredQty = data.DemandDeliveredQty
		responseItem.DemandCtrlTime1 = data.DemandCtrlTime1
		responseItem.DemandCtrlTime2 = data.DemandCtrlTime2
		responseItem.DemandCtrlPara4 = data.DemandCtrlPara4
		responseItem.DemandCtrlPara3 = data.DemandCtrlPara3
		responseItem.DemandCtrlPara2 = data.DemandCtrlPara2
		responseItem.DemandCtrlPara1 = data.DemandCtrlPara1
		responseItem.PlantNr = data.PlantNr
		responseItem.DemandYear = data.DemandYear
		responseItem.DemandMonth = data.DemandMonth
		responseItem.DemandWeek = data.DemandWeek
		responseItem.DemandHour = data.DemandHour
		responseItem.DemandQty = data.DemandQty
		responseItem.DemandSendTime = data.DemandSendTime
		responseItem.DemandRecieveTime = data.DemandRecieveTime
		responseItem.DemandConfirmTime = data.DemandConfirmTime
		responseItem.DemandCloseTime = data.DemandCloseTime
		responseItem.DemandId = data.DemandId
		responseItem.LastModify = data.LastModify
		responseItem.LastUser = data.LastUser
		responseItem.CreateTime = data.CreateTime
		responseItem.DemandObjId = data.DemandObjId
		article, err := baseDao.SelectOne(artDemandLst.ArtId)
		if err != nil {
			return nil, err
		}
		if article != nil {
			responseItem.ArtDesc = article.Descr1
		}
		if artDemandLst.Status == model.AccomplishedStatus {
			responseItem.UrgencyDegree = "不紧急"
			responseItem.SurplusDays = 0
		} else {
			demandDate := artDemandLst.DemandDate.Restore()

			days := (demandDate.Unix() - today.Unix()) / 86400
			responseItem.SurplusDays = days
			if days > 2 {
				responseItem.UrgencyDegree = "不紧急"
			} else if days >= 0 && days <= 2 {
				responseItem.UrgencyDegree = "紧急"
			} else {
				responseItem.UrgencyDegree = "延误"
			}
		}
		responseLi = append(responseLi, responseItem)
	}
	temp := make([]interface{}, len(responseLi))
	for index, item := range responseLi {
		temp[index] = item
	}
	//titleList := make([]string, 0)
	titleList := []string{
		"工厂ID",
		"物料ID",
		"需求时间",
		"需求ID",
		"需求年份",
		"需求月份",
		"需求周",
		"需求日期",
		"需求时",
		"需求数量",
		"数量单位",
		"需求对象ID",
		"需求类型",
		"状态",
		"需求发送时间",
		"需求接收时间",
		"需求确认时间",
		"需求关闭时间",
		"需求发运数量",
		"需求控制参数1",
		"需求控制参数2",
		"需求控制参数3",
		"需求控制参数4",
		"需求时间参数1",
		"需求时间参数2",
		"最后修改时间",
		"最后操作人",
		"创建时间",
		"物料描述",
		"紧急程度",
		"剩余交付天数",
	}

	filepath, err := grmi.SaveExcelFile(temp, titleList, "供应商需求明细", "供应商需求明细")
	if err != nil {
		return nil, grmi.NewBusinessError(fmt.Sprintf("导出报表失败，请重试, errors: %s", err.Error()))
	}
	return filepath, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/ArtDemandLstService.ChangeArtDemandLstStatus
 *
 ******************************************************************************/
func (impl *ArtDemandLstServiceImplement) ChangeArtDemandLstStatus(user *models.Usertab, records []model.ArtDemandLstStatusChange, operateType string) error {
	grmi.Log(user, "/services/log/implments/LOG_ArtDemandLst.service.impl.go", "ChangeArtDemandLstStatus", "ArtDemandLst状态修改为接收")
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	err := session.Begin()
	if err != nil {
		return err
	}
	dao := dal.NewArtDemandLstDAO(session, user.Pid, user.Userid)
	artDemandLstList := make([]model.ArtDemandLst, len(records))
	// 校验每个ArtDemandLst的状态 再修改status
	for index, record := range records {
		dateString := record.DemandTime
		date, err := time.Parse("2006-01-02 15:04:05", dateString)
		if err != nil {
			return grmi.NewRequestError(errors.New(fmt.Sprintf("请求参数demandTime错误: %s", err.Error())))
		}
		artDemandLst, err := dao.SelectOne(record.ArtId, grmi.DateTime(date))
		if err != nil {
			return err
		}
		if artDemandLst == nil {
			return grmi.NewBusinessError(fmt.Sprintf("该条数据不存在, artId: %s, demandTime: %s", record.ArtId, record.DemandTime))
		}
		switch operateType {
		case "receive":
			if artDemandLst.Status != model.WaitReceivingStatus {
				return grmi.NewBusinessError(fmt.Sprintf("计划明细状态与您的操作不相符,artID: %s demandTime: %s", record.ArtId, record.DemandTime))
			}
			artDemandLst.Status = model.ReceivedStatus
			artDemandLst.DemandRecieveTime = grmi.DateTime(time.Now())
		case "confirm":
			if artDemandLst.Status != model.ReceivedStatus {
				return grmi.NewBusinessError(fmt.Sprintf("计划明细状态与您的操作不相符,artID: %s demandTime: %s", record.ArtId, record.DemandTime))
			}
			artDemandLst.Status = model.ConfirmedStatus
			artDemandLst.DemandConfirmTime = grmi.DateTime(time.Now())
		case "accomplish":
			if artDemandLst.Status != model.ConfirmedStatus {
				return grmi.NewBusinessError(fmt.Sprintf("计划明细状态与您的操作不相符,artID: %s demandTime: %s", record.ArtId, record.DemandTime))
			}
			artDemandLst.Status = model.AccomplishedStatus
			artDemandLst.DemandCloseTime = grmi.DateTime(time.Now())
		}
		artDemandLstList[index] = *artDemandLst
	}
	err = dao.Update(&artDemandLstList)
	if err != nil {
		session.Rollback()
		return err
	}
	err = session.Commit()
	if err != nil {
		return err
	}
	return nil
}
