// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package log

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	model "LAPP_GAAS_GFrame_BACKEND/models/log"
	"LAPP_GAAS_GFrame_BACKEND/web/middleware/jwts"
	"LAPP_GAAS_GFrame_BACKEND/web/models"
	"LAPP_GAAS_GFrame_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	"time"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterOneArtDemandLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ArtDemandLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArtDemandLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterIDOfArtDemandLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, grmi.DateTime) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")
		demandTimeOrigin, err := time.Parse(grmi.URLDateTimeFormat, ctx.Params().GetString("demandTime"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
		}
		demandTime := grmi.DateTime(demandTimeOrigin)

		err = method(user, artId, demandTime)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertOneArtDemandLst(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandLst) error) {

	RegisterOneArtDemandLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteOneArtDemandLst(party router.Party, path string, method func(*models.Usertab, string, grmi.DateTime) error) {

	RegisterIDOfArtDemandLst(party, "DELETE", path+"/{artId:string}/{demandTime:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectOneArtDemandLst(party router.Party, path string, method func(*models.Usertab, string, grmi.DateTime) (*model.ArtDemandLst, error)) {

	party.Get(path+"/{artId:string}/{demandTime:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		artId := ctx.Params().GetString("artId")
		demandTimeOrigin, err := time.Parse(grmi.URLDateTimeFormat, ctx.Params().GetString("demandTime"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
		}
		demandTime := grmi.DateTime(demandTimeOrigin)
		result, err := method(user, artId, demandTime)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateOneArtDemandLst(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandLst) error) {

	RegisterOneArtDemandLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterMultiArtDemandLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ArtDemandLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ArtDemandLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertArtDemandLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandLst) error) {

	RegisterMultiArtDemandLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteArtDemandLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandLst) error) {

	RegisterMultiArtDemandLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectArtDemandLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateArtDemandLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandLst) error) {

	RegisterMultiArtDemandLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterExportArtDemandLstList
 *-----------------------------------------------------------------------------
 *
 * @Description              : 导出供应商需求明细报表
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-03-19
 *
 ******************************************************************************/
func RegisterExportArtDemandLstList(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterReceiveArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 供应商需求明细接收
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-03-19
 *
 ******************************************************************************/
func RegisterReceiveArtDemandLst(party router.Party, path string, method func(*models.Usertab, []model.ArtDemandLstStatusChange, string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var records model.ArtDemandLstStatusChangeRecords
		if err := ctx.ReadJSON(&records); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, records.Records, "receive")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterConfirmArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 供应商需求明细确认
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-03-19
 *
 ******************************************************************************/
func RegisterConfirmArtDemandLst(party router.Party, path string, method func(*models.Usertab, []model.ArtDemandLstStatusChange, string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var records model.ArtDemandLstStatusChangeRecords
		if err := ctx.ReadJSON(&records); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, records.Records, "confirm")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterAccomplishArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 供应商需求明细完成
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-03-19
 *
 ******************************************************************************/
func RegisterAccomplishArtDemandLst(party router.Party, path string, method func(*models.Usertab, []model.ArtDemandLstStatusChange, string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var records model.ArtDemandLstStatusChangeRecords
		if err := ctx.ReadJSON(&records); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, records.Records, "accomplish")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
